from pydantic import BaseModel
import json


class C(BaseModel):
    x: int


class B(BaseModel):
    str_var: str
    int_var: int
    float_var: float
    bool_var: bool
    optional_str_var: str | None = None
    dict_var: dict = {}
    list_var: list = [1, 2, 3]
    set_var = set()
    bytes_var = b"123"
    obj_var: C


b = json.loads(B.schema_json())
b = B.schema()
print(b)
# print(b)
# for k, v in b["properties"].items():
#     print(k, v)


class PysuraEnv(BaseModel):

    selected_billing_account: str = None
    billing_accounts: list = []


# Handle all stdin/stdout with reading, writing, flushing, and try to build interactive commands
# https://python-prompt-toolkit.readthedocs.io/en/master/pages/getting_started.html


class ConsolePipe:

    pass


from cmd import Cmd
import json
import site
import os


class Root(Cmd):
    SITE_PACKAGES_URL = site.getsitepackages()[0]

    @staticmethod
    def find_path(file_name: str = "env.json"):
        return os.path.join(Root.SITE_PACKAGES_URL, "pysura", "library_data", file_name)

    @property
    def env(self) -> dict:
        try:
            with open(Root.find_path(), "r") as f:
                return json.load(f)
        except FileNotFoundError:
            with open(Root.find_path(), "w") as f:
                json.dump({}, f)
                return {}

    @env.setter
    def env(self, value: dict):
        try:
            with open(Root.find_path(), "w") as f:
                json.dump(value, f)
        except FileNotFoundError:
            with open(Root.find_path(), "w") as f:
                json.dump({}, f)
